Crate libdd_alloc

Crate libdd_alloc 

Modules

os

Structs

AllocError
The AllocError error indicates an allocation failure that may be due to resource exhaustion or to something wrong when combining the given input arguments with this allocator.
ChainAllocator
ChainAllocator is an arena allocator, meaning that deallocating individual allocations made by this allocator does nothing. Instead, the whole backing memory is dropped at once. Destructors for these objects are not called automatically and must be done by the caller if it’s necessary.
Layout
Layout of a block of memory.
LayoutError
The LayoutError is returned when the parameters given to Layout::from_size_align or some other Layout constructor do not satisfy its documented constraints.
LinearAllocator
LinearAllocator is an arena allocator, meaning that deallocating individual allocations made by this allocator does nothing. Instead, the whole backing memory is dropped at once. Destructors for these objects are not called automatically and must be done by the caller if it’s necessary.
VirtualAllocator
Allocates entire pages of virtual memory for each allocation. This is intended for large allocations only, such as working with other allocators to provide a large chunk for them.

Traits

Allocator
An implementation of Allocator can allocate, grow, shrink, and deallocate arbitrary blocks of data described via Layout.
GlobalAlloc
A memory allocator that can be registered as the standard library’s default through the #[global_allocator] attribute.