pub struct VirtualAllocator {}Expand description
Allocates entire pages of virtual memory for each allocation. This is intended for large allocations only, such as working with other allocators to provide a large chunk for them.